RootTransforms

Struct RootTransforms 

pub struct RootTransforms {
    transforms: SmallVec<[Affine; 3]>,
}
Stack of root transforms.

Fields

transforms: SmallVec<[Affine; 3]>

Implementations

Source

impl RootTransforms

pub fn new() -> Self

Create a new root transform stack.

pub fn root_transform(&self) -> Affine

Return the root transform of the currently active root viewport, including shifts inherited from nested filters.

pub fn effective_path_transform(&self, transforms: &Transforms) -> Affine

Return the transform used for rendering paths.

pub fn effective_paint_transform(&self, transforms: &Transforms) -> Affine

Return the transform used for rendering paints.

pub fn push_root(&mut self, relative_transform: Affine)

Push a new root transform relative to the currently active root transform.

pub fn pop_root(&mut self)

Pop the last root layer.

pub fn reset(&mut self)

Reset the root transform stack.